@@ -290,6 +290,7 @@ pub struct PortableExecutable<'a> {
     context: NtContext,
     added_to_hash_tbl: bool,
     added_to_index: bool,
+    added_to_peb: bool,
     called_entry_point: bool,
     last_primary: Option<PVOID>,
 }
@@ -349,9 +350,7 @@ impl<'a> PortableExecutable<'a> {
                         || ((*l).TimeDateStamp <= (*r).TimeDateStamp
                             && (*l).SizeOfImage < (*r).SizeOfImage)
                 },
-            )
-        }
-        unsafe {
+            );
             rtl_rb_tree_insert(
                 &mut self.context.LdrpModuleBaseAddressIndex.lock(),
                 &mut self.loader_entry.BaseAddressIndexNode,
@@ -365,22 +364,6 @@ impl<'a> PortableExecutable<'a> {
         self.added_to_index = true;
     }
 
-    /// Adds the module to the PEB structures
-    fn add_to_peb(&mut self) {
-        unsafe {
-            let peb = NtCurrentPeb();
-            let ldr = (*peb).Ldr;
-            InsertTailList(
-                &mut (*ldr).InLoadOrderModuleList,
-                &mut self.loader_entry.InLoadOrderLinks
-            );
-            InsertTailList(
-                &mut (*ldr).InMemoryOrderModuleList,
-                &mut self.loader_entry.InMemoryOrderLinks
-            );
-        }
-    }
-    
     /// Removes the module from the index red-black trees
     fn remove_from_index(&mut self) {
         unsafe {
@@ -395,6 +378,31 @@ impl<'a> PortableExecutable<'a> {
         }
     }
 
+    /// Adds the module to the PEB structures
+    fn add_to_peb(&mut self) {
+        unsafe {
+            let peb = NtCurrentPeb();
+            let ldr = (*peb).Ldr;
+            InsertTailList(
+                &mut (*ldr).InLoadOrderModuleList,
+                &mut self.loader_entry.InLoadOrderLinks,
+            );
+            InsertTailList(
+                &mut (*ldr).InMemoryOrderModuleList,
+                &mut self.loader_entry.InMemoryOrderLinks,
+            );
+        }
+        self.added_to_peb = true;
+    }
+
+    /// Removes the modules from the PEB structures
+    fn remove_from_peb(&mut self) {
+        unsafe {
+            RemoveEntryList(&mut self.loader_entry.InLoadOrderLinks);
+            RemoveEntryList(&mut self.loader_entry.InMemoryOrderLinks);
+        }
+    }
+
     /// Calls the function entry point
     ///
     /// # Arguments
@@ -676,6 +684,7 @@ impl<'a> PortableExecutable<'a> {
             context,
             added_to_hash_tbl: false,
             added_to_index: false,
+            added_to_peb: false,
             called_entry_point: false,
             last_primary: None,
         };
@@ -925,6 +934,10 @@ impl<'a> Drop for PortableExecutable<'a> {
         if let Err(e) = self.disable_exceptions() {
             debug!("Failed to disable exceptions: {}", e.to_string())
         }
+        // remove ourselves from the PEB
+        if self.added_to_peb {
+            self.remove_from_peb();
+        }
         // remove ourselves from the index RB trees
         if self.added_to_index {
             self.remove_from_index();
